# Tutorials: Implementing complex algorithms in geqo

The notebooks in this sections show how quantum algorithms can be build and executed on a simulator with geqo.

- **Example for Quantum-Amplitude-Estimation**: The Quantum Amplitude Estimation is applied to a simple example circuit and the probability of a measurement result is estimated with 4 bits of precesion.
- **Quantum Amplitude Estimation of risk models**: A quantum version of a business risk model is constructed and the Quantum Amplitude Estimation is used to estimate the probability of an event in the model.

